@@ -148,7 +148,7 @@ mlm_path_plot <- function(mod = NULL, xlab = "X", ylab = "Y", mlab = "M",
             paste0("c = ", c[1], " [", c[3], ", ", c[4], "]"), pos=4)
         graphics::text(
             -1.2, 0.9,
-            paste0("%me = ", pme[1], " [", pme[3], ", ", pme[4], "]"), pos=4)
+            paste0("pme = ", pme[1], " [", pme[3], ", ", pme[4], "]"), pos=4)
         if (is.null(id)){
             graphics::text(
                 -1.2, 0.75,
@@ -306,8 +306,14 @@ mlm_pars_plot <- function(mod = NULL,
 #' @param n Number of points along X to evaluate fitted values on.
 #' See details.
 #' @param binary_y Set to TRUE if the outcome variable (Y) is 0/1.
+#' @param mx Should the X axis of the M-Y figure be "fitted" values,
+#' or "data" values. Defaults to "fitted".
 #' @param fixed Should the population-level ("fixed") fitted values be shown?
 #' @param random Should the subject-level ("random") fitted values be shown?
+#' @param h_jitter Horizontal jitter of points. Defaults to 0.
+#' @param v_jitter Vertical jitter of points. Defaults to 0.
+#' @param bar_width Width of the error bars. Defaults to 0.2.
+#' @param bar_size Thickness of the error bars. Defaults to 0.75.
 #' @param n_samples Number of MCMC samples to use in calculating fitted values.
 #' See details.
 #'
@@ -330,8 +336,16 @@ mlm_pars_plot <- function(mod = NULL,
 #' @export
 mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
                                id = "id", x="x", m="m", y="y",
-                               level = .95, n = 12, binary_y = FALSE,
-                               fixed = TRUE, random = TRUE,
+                               level = .95,
+                               n = 12,
+                               binary_y = FALSE,
+                               mx = "fitted",
+                               fixed = TRUE,
+                               random = TRUE,
+                               h_jitter = 0,
+                               v_jitter = 0,
+                               bar_width = .2,
+                               bar_size = .75,
                                n_samples = NA) {
 
     # Check for model
@@ -339,6 +353,8 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
     # Check for data
     if (is.null(d)) stop("No data object entered.")
     if (class(d)[1] == "tbl_df") d <- as.data.frame(d)  # Allow tibbles
+    # Make IDs sequential
+    d$id = as.integer(as.factor(as.character(d[, id])))
     # At least one of fixed, random = TRUE
     if (!any(fixed, random)) stop("fixed or random (or both) must be TRUE.")
 
@@ -366,9 +382,15 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
         M$m_fitted_upper <- apply(Mfit, 1, quantile, prob = .5 + level/2)
 
         # Calculate fitted values of Y based on fitted values of M
-        Y <- data.frame(m = seq(min(M$m_fitted_mean),
-                                max(M$m_fitted_mean),
-                                length = n))
+        if (mx == "fitted") {
+            Y <- data.frame(m = seq(min(M$m_fitted_mean),
+                                    max(M$m_fitted_mean),
+                                    length = n))
+        } else {
+            Y <- data.frame(m = seq(min(d[,m]),
+                                    max(d[,m]),
+                                    length = n))
+        }
         names(Y) <- m
         YX <- model.matrix(as.formula(paste(" ~ 1 +", m)), data=Y)
         Yfit <- matrix(ncol = nrow(post), nrow = nrow(YX))
@@ -405,7 +427,7 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
             names(tmp) <- c(id, x)
             M_vary <- rbind(M_vary, tmp)
         }
-        M_vary[,id] = as.integer(as.factor(as.character(M_vary[,id])))
+        M_vary[,id] = as.factor(as.character(M_vary[,id]))
 
         M_vary <- merge(M_vary, U[,c(id, "u_dm", "u_a")])
         M_vary$m_fitted_mean <- M_vary$u_dm + M_vary$u_a*M_vary[,x]
@@ -415,9 +437,15 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
         names(Y_vary) <- c(id, m)
         # Create even grid of fitted_m predictor per subject
         for (s in unique(M_vary[,id])) {
-            m_fitted_mean <- seq(min(M_vary$m_fitted_mean[M_vary[,id]==s]),
-                                 max(M_vary$m_fitted_mean[M_vary[,id]==s]),
-                                 length = n)
+            if (mx == "fitted") {
+                m_fitted_mean <- seq(min(M_vary$m_fitted_mean[M_vary[,id]==s]),
+                                     max(M_vary$m_fitted_mean[M_vary[,id]==s]),
+                                     length = n)
+            } else {
+                m_fitted_mean <- seq(min(d[,m][d[,id]==s]),
+                                     max(d[,m][d[,id]==s]),
+                                     length = n)
+            }
             tmp <- data.frame(id = s,
                               m = m_fitted_mean)
             names(tmp) <- c(id, m)
@@ -446,7 +474,8 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
                                   aes_(x=as.name(x),
                                        y=as.name("m_fitted_mean"),
                                        group=as.name(id)),
-                                  alpha=.25)
+                                  alpha=.25,
+                                  position = position_jitter(h_jitter, v_jitter))
         }
     }
     if (fixed) {
@@ -465,7 +494,9 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
                                      aes_(x = as.name(x),
                                           ymin = as.name("m_fitted_lower"),
                                           ymax = as.name("m_fitted_upper")),
-                                     alpha=.8)
+                                     alpha=.8,
+                                     width = bar_width,
+                                     size = bar_size)
             pm <- pm + geom_point(data = M,
                                   aes_(x = as.name(x),
                                        y = as.name("m_fitted_mean")),
@@ -490,7 +521,8 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
                                   aes_(x=as.name(m),
                                        y=as.name("y_fitted_mean"),
                                        group=as.name(id)),
-                                  alpha=.25)
+                                  alpha=.25,
+                                  position = position_jitter(h_jitter, v_jitter))
         }
     }
     if (fixed) {
@@ -506,10 +538,12 @@ mlm_spaghetti_plot <- function(mod=NULL, d=NULL,
                                  size=1)
         } else {
             py <- py + geom_errorbar(data = Y,
-                                   aes_(x = as.name(m),
-                                        ymin = as.name("y_fitted_lower"),
-                                        ymax = as.name("y_fitted_upper")),
-                                   alpha=.8)
+                                     aes_(x = as.name(m),
+                                          ymin = as.name("y_fitted_lower"),
+                                          ymax = as.name("y_fitted_upper")),
+                                     alpha=.8,
+                                     width = bar_width,
+                                     size = bar_size)
             py <- py + geom_point(data = Y,
                                   aes_(x = as.name(m),
                                        y = as.name("y_fitted_mean")),
